********************************************************************************
* Programs for survey-based inference on dataset from Malawi
* with six waves, twenty lots, and three yes/no outcomes.
* 
* These programs requires several additional user-written programs
* that are found in a sub-folder named programs_to_make_inchworm_plots.
*
*
* Written by Dale Rhoda, Biostat Global Consulting, July 20, 2016
* E-mail:    Dale.Rhoda@biostatglobal.com
* Skype:     dalerhoda
* Phone:	 +1 614 499-2351
*
* Do not hesitate to contact me with questions.
* 
********************************************************************************

set more off

cd "$folder"

import excel "${folder}\Population and sample data LQAS Malawi.xlsx", sheet("Pop & sample data LQAS Malawi") clear cellrange(A2:AD21)

rename A lotname

gen lotid = _n

rename B pop_total
rename C pop_under5

rename D pop1
replace pop1 = round(pop1,1)
label variable pop1 "Pop: 6w-4 months"

rename E pop2
replace pop2 = round(pop2,1)
label variable pop2 "Pop: 4-16 months"

rename F n16
drop G
rename H n26
drop I
drop J
rename K n15
drop L
rename M n25
drop N
rename O n14
drop P
rename Q n24
drop R
rename S n13
drop T
rename U n23
drop V
rename W n12
drop X
rename Y n22
drop Z
rename AA n11
drop AB
rename AC n21
drop AD

* Some of the population figures in the spreadsheet are SMALLER
* than the number of kids sampled...so adjust the population upward
* if necessary; give every stratum a bonus of 1 so we are sure to
* obtain positive standard errors for making inchworm plots

replace pop1 = max(pop1, n11, n12, n13, n14, n15, n16) + 1
replace pop2 = max(pop2, n21, n22, n23, n24, n25, n26) + 1

* Reshape long so there is one row per lot / cohort / wave
reshape long n1 n2, i(lotname lotid pop_total pop_under5 pop1 pop2) j(wave)
reshape long pop n, i(lotname lotid pop_total pop_under5 wave) j(cohort)

save malawi-step01-premerge, replace


