********************************************************************************
* Programs for survey-based inference on dataset from Malawi
* with six waves, twenty lots, and three yes/no outcomes.
* 
* These programs requires several additional user-written programs
* that are found in a sub-folder named programs_to_make_inchworm_plots.
*
*
* Written by Dale Rhoda, Biostat Global Consulting, July 20, 2016
* E-mail:    Dale.Rhoda@biostatglobal.com
* Skype:     dalerhoda
* Phone:	 +1 614 499-2351
*
* Do not hesitate to contact me with questions.
* 
********************************************************************************

set more off

cd "$folder"

local age_eligible_1 =  6*7
local age_eligible_2 = 10*7								  
local age_eligible_3 = 14*7

use PCV13combined, clear
rename villageclinicname lotname
rename lqas wave
recode agegroup (0=1) (1=2), gen(cohort)

merge m:1 lotname wave cohort using malawi-step01-premerge.dta 

gen weight = pop / n

egen stratum = group(lotid wave cohort), label

svyset _n [pweight = weight], strata(stratum) fpc(pop) single(certainty)

gen age_at_survey = datacollectiondate - dateofbirth
replace age_at_survey = dcollect - dbirth if missing(age_at_survey )
label variable age_at_survey "Age at Survey (days)"

label define gotit 0 "No" 1 "Yes", replace

label values pcv1 gotit
label values pcv2 gotit
label values pcv3 gotit

* Remove child from denominator if they were not age-eligible for the dose
forvalues i = 1/3 {
	replace pcv`i' = . if age_at_survey < `age_eligible_`i''
}

save malawi_svyset_dataset, replace


