//PCV13 Combined - estimates of vaccine coverage over time (by age) - Tim Colbourn 8th Jan 2015
cd "/Users/timothycolbourn/Documents/Gates Malawi Pnuemonia/LQAS/LQAS paper/Gates Open Research paper/PCV13 Malawi UK Data Service files"
set more off
log using "PCV13 Combined.smcl", replace
	//get data from each of the LQAS surveys, label them and merge datasets
use "PCV13combined.dta", clear
	
*Shouldn't be any need to clean ages, but check oldest and youngest:
summ age1 age2 age3

tab month lqasdate, m

gen obs=1
collapse (sum) obs pcv1 pcv2 pcv3, by(month lqasdate)
gen pcv1p = (pcv1/obs)*100 //generate percentage of babies with 1 dose
gen pcv2p = (pcv2/obs)*100 //generate percentage of babies with 2 doses
gen pcv3p = (pcv3/obs)*100 //generate percentage of babies with 3 doses

	//all three doses
twoway (line pcv3p lqasdate if month==6, lcolor(orange*0.05)) ///
	(line pcv3p lqasdate if month==7, lcolor(orange*0.1)) ///
	(line pcv3p lqasdate if month==8, lcolor(orange*0.2)) ///
	(line pcv3p lqasdate if month==9, lcolor(orange*0.3)) ///
	(line pcv3p lqasdate if month==10, lcolor(orange*0.4)) ///
	(line pcv3p lqasdate if month==11, lcolor(orange*0.5)) ///
	(line pcv3p lqasdate if month==12, lcolor(orange*0.6)) ///
	(line pcv3p lqasdate if month==13, lcolor(orange*0.7)) ///
	(line pcv3p lqasdate if month==14, lcolor(orange*0.8)) ///
	(line pcv3p lqasdate if month==15, lcolor(orange*0.9)) ///
	(line pcv3p lqasdate if month==16, lcolor(orange)) ///
	, ylabel(, format(%3.0f) labsize(small) angle(0)) ///
	ytitle("Percentage of Babies", size(small)) ///
	xlabel(#30, labsize(small) angle(90)) ///
	xtitle("Month", size(small)) ///
	title("Percentage of babies 6-16 months old vaccinated with all 3 PCV doses", size(small)) ///
	legend(on) legend(order(1 "6 months old" 2 "7 months old" 3 "8 months old" ///
							4 "9 months old" 5 "10 months old" 6 "11 months old" ///
							7 "12 months old" 8 "13 months old" 9 "14 months old" ///
							10 "15 months old" 11 "16 months old") col(3) colfirst size(small))
graph save "FullyVaccinated_byLQAS_byMonthsOld.gph", replace
graph export FullyVaccinated_byLQAS_byMonthsOld.pdf, as(pdf) replace

	//only 2 doses, which may be enough (see Goldblatt 2006)
twoway (line pcv2p lqasdate if month==6, lcolor(navy*0.05)) ///
	(line pcv2p lqasdate if month==7, lcolor(navy*0.1)) ///
	(line pcv2p lqasdate if month==8, lcolor(navy*0.2)) ///
	(line pcv2p lqasdate if month==9, lcolor(navy*0.3)) ///
	(line pcv2p lqasdate if month==10, lcolor(navy*0.4)) ///
	(line pcv2p lqasdate if month==11, lcolor(navy*0.5)) ///
	(line pcv2p lqasdate if month==12, lcolor(navy*0.6)) ///
	(line pcv2p lqasdate if month==13, lcolor(navy*0.7)) ///
	(line pcv2p lqasdate if month==14, lcolor(navy*0.8)) ///
	(line pcv2p lqasdate if month==15, lcolor(navy*0.9)) ///
	(line pcv2p lqasdate if month==16, lcolor(navy)) ///
	, ylabel(, format(%3.0f) labsize(small) angle(0)) ///
	ytitle("Percentage of Babies", size(small)) ///
	xlabel(#30, labsize(small) angle(90)) ///
	xtitle("Month", size(small)) ///
	title("Percentage of babies 6-16 months old vaccinated with 2 PCV doses", size(small)) ///
	legend(on) legend(order(1 "6 months old" 2 "7 months old" 3 "8 months old" ///
							4 "9 months old" 5 "10 months old" 6 "11 months old" ///
							7 "12 months old" 8 "13 months old" 9 "14 months old" ///
							10 "15 months old" 11 "16 months old") col(3) colfirst size(small))
graph save "2dosesVaccinated_byLQAS_byMonthsOld.gph", replace
graph export 2dosesVaccinated_byLQAS_byMonthsOld.pdf, as(pdf) replace


summ pcv1p pcv2p pcv3p //look at mean for % vaccinated with each dose
bys month: summ pcv1p pcv2p pcv3p

save PCV13combined_month.dta, replace

** Table 1
use PCV13combined.dta
	* n
tab lqas lqasdate, m
	* Age
bys lqasdate: tab agegroup, m
tab agegroup, m
	* Median age in weeks at vaccination (IQR)
//	gen age1w = age1/7
//	gen age2w = age2/7
//	gen age3w = age3/7
bys lqasdate: summ age1w age2w age3w, d	
summ age1w age2w age3w, d
	* Health passports 
/*	gen hpassport=.
	recode hpassport (.=0) if healthpassport==0 | hashealthpassport==0 | HealthPassport==0 | HealthPassportavailable==0
	recode hpassport (.=1) (0=1) if healthpassport==1 | hashealthpassport==1 | HealthPassport==1 | HealthPassportavailable==1 */
tab hpassport, m
bys lqasdate: tab hpassport, m
	* Vaccination coverage
bys lqasdate: tab pcv1
bys lqasdate: tab pcv2
bys lqasdate: tab pcv3
bys lqasdate agegroup: tab pcv1
bys lqasdate agegroup: tab pcv2
bys lqasdate agegroup: tab pcv3
	* Timeliness
		* dose 1 - 6  weeks [4  weeks to 2 months]
/* gen pcv1timely = 0
tab pcv1, m
recode pcv1timely (0=1) if pcv1==1
recode pcv1timely (1=0) if age1<28 // number too early (i.e before 4 weeks)
recode pcv1timely (1=0) if age1>((365.25/12)*2) // number too late (i.e. after 2 months) */
tab pcv1timely, m
bys lqasdate: tab pcv1timely, m
		* dose 2 - 10 weeks [8  weeks to 4 months]
/* gen pcv2timely = 0
tab pcv2, m
recode pcv2timely (0=1) if pcv2==1
recode pcv2timely (1=0) if age2<56 // number too early (i.e before 8 weeks)
recode pcv2timely (1=0) if age2>((365.25/12)*4) // number too late (i.e. over 4 months) */
tab pcv2timely, m
bys lqasdate: tab pcv2timely, m	
		* dose 3 - 14 weeks [12 weeks to 6 months]
/* gen pcv3timely = 0
tab pcv3, m
recode pcv3timely (0=1) if pcv3==1
recode pcv3timely (1=0) if age3<84 // number too early (i.e before 12 weeks)
recode pcv3timely (1=0) if age3>((365.25/12)*6) // number too late (i.e. over 6 months) */
tab pcv3timely, m
bys lqasdate: tab pcv3timely, m
		* All 3 doses timely
/* gen timely = 0
recode timely (0=1) if pcv1timely==1 & pcv2timely==1 & pcv3timely==1 */
tab timely
bys lqasdate: tab timely
		
*compress
*save PCV13combined.dta, replace

log close
